@@ -91,11 +91,11 @@ proc FileDirBrowser {args} {
 ######################################################################
 
 proc File-Browser {name args} {
-  global argv
+  global argv __language
   parseOpt {showHidden exist} {text default dir pattern} $args
   if {$options(dir) == "" && $options(dircmd) == ""} {
     error "A -dir option is needed for File-Browser" \
-        "otherwise I don't know where to get the file from!"
+      "otherwise I don't know where to get the file from!"
   }
 
   Entry $name -text [join $options(text)] -packEntry:expand 1 \
@@ -206,7 +206,7 @@ proc File-Dir-Browser {name args} {
 ### of the three above should be used.
 ######################################################################
 proc browser {dir file filePattern showHidden exists showFile showDir} {
-  global __browser
+  global __browser __language
 
   set dirOrig $dir
   if {[string index $dir [expr [string length $dir]-1]] != "/" &&
@@ -290,6 +290,7 @@ proc browser {dir file filePattern showHidden exists showFile showDir} {
 ### This function takes care of packing the browser
 ######################################################################
 proc packBroswer {showDir showFiles} {
+  global __language
   set w [toplevel .browse]
 
   ### The outer frames
@@ -314,10 +315,10 @@ proc packBroswer {showDir showFiles} {
     entry $path.entry
     bind $path.entry <Return> "browser_select $path.box $prefix"
     if {$prefix == "files"} {
-      $path.label configure -text Files:
+      $path.label configure -text $__language(browser,1)
       $path.entry configure -textvariable __browser(file)
     } else {
-      $path.label configure -text Directories:
+      $path.label configure -text $__language(browser,2)
       $path.entry configure -textvariable __browser(dirEntry)
     }
     listbox $path.box  -yscrollcommand "$path.scroll set" -width 0 \
@@ -356,12 +357,16 @@ proc packBroswer {showDir showFiles} {
 
   ### buttons
   set buts $w.buts
-  button $buts.ok -text OK -command browse_ok
-  button $buts.cancel -text Cancel -command {
+
+  # OK
+  button $buts.ok -text $__language(ok) -command browse_ok
+
+  # Cancel
+  button $buts.cancel -text $__language(cancel) -command {
     set __browser(exit) cancel
     destroy .browse
   }
-  checkbutton $buts.showHidden -text "Show Hidden\nFiles" \
+  checkbutton $buts.showHidden -text $__language(browser,5) \
       -variable __browser(showHidden) -justify left \
       -command browse_checkboxSelcted
   pack $buts.ok $buts.cancel $buts.showHidden -anchor w -pady 2 -fill x
@@ -371,7 +376,7 @@ proc packBroswer {showDir showFiles} {
 ### This function insert directories into the directory listbox
 ######################################################################
 proc insertDirectories {dir hidden} {
-  global __browser
+  global __browser __language
   set w .browse.dirs.box
   $w delete 0 end
 
@@ -383,7 +388,7 @@ proc insertDirectories {dir hidden} {
   }
 
   if {![file readable $dir]} {
-    tk_dialog .warning "Warning" "Directory is not readable" info 0 OK
+    tk_dialog .warning $__language(warning) $__language(browser,7) info 0 $__language(ok)
     return
   }
 
@@ -415,7 +420,7 @@ proc insertDirectories {dir hidden} {
 ### This functoin insert files into the fileListbox.
 ######################################################################
 proc insertFiles {dir filePattern activeFile hidden} {
-  global __browser
+  global __browser __language
   set w .browse.files.box
   $w delete 0 end
   if {![file readable $dir]} {
@@ -443,7 +448,7 @@ proc insertFiles {dir filePattern activeFile hidden} {
 ### in one of the entries.
 ######################################################################
 proc browser_select {path prefix} {
-  global __browser
+  global __browser __language
   if {$prefix == "files"} {
     if {[regexp {\*|\?} $__browser(file)]} {
       ### a pattern were inserted.
@@ -470,7 +475,7 @@ proc browser_select {path prefix} {
       }
       set __browser(dirs) ""
       set __browser(files) ""
-      tk_dialog .dialog "Error" "Directory does not exists." error 0 OK
+      tk_dialog .dialog $__language(error) $__language(browser,10) error 0 $__language(ok)
     } else {
       ### The directory exists.
       set __browser(dir) $__browser(dirEntry)
@@ -488,7 +493,7 @@ proc browser_select {path prefix} {
 ### directory to change to it.
 ######################################################################
 proc browse_changeDir {path x y} {
-  global __browser
+  global __browser __language
   set value [$path get [$path index @$x,$y]]
 
   ### The user selected ".."
@@ -515,7 +520,7 @@ proc browse_changeDir {path x y} {
 ### is changed.
 ######################################################################
 proc browse_checkboxSelcted {} {
-  global __browser
+  global __browser __language
 
   if {$__browser(showDir)} {
     insertDirectories $__browser(dir) $__browser(showHidden)
@@ -527,29 +532,29 @@ proc browse_checkboxSelcted {} {
 }
 
 proc browse_ok {} {
-  global __browser
+  global __browser __language
 
   ### test that the filename is valid.
   if {$__browser(showFile)} {
     if {[regexp {\*|\\|\?|\{|\}} $__browser(file)] || $__browser(file) == ""} {
-      tk_dialog .error ERROR "Invalid filename: \"$__browser(file)\"" error 0 OK
+      tk_dialog .error $__language(error) [langExp "%s" $__browser(file) $__language(browser,13)] error 0 $__language(ok)
       return
     }
     if {$__browser(exists) && ![file exists $__browser(dir)$__browser(file)]} {
-      tk_dialog .error ERROR "File does not exist: \"$__browser(file)\"" \
-          error 0 OK
+      tk_dialog .error $__langauge(error) [langExp "%s" $__browser(file) $__language(browser,14)] \
+          error 0 $__language(ok)
       return
     }
   } else {
     if {[regexp {\*|\\|\?|\{|\}} $__browser(dirEntry)] ||
         $__browser(dirEntry) == ""} {
-      tk_dialog .error ERROR "Invalid directory name: \"$__browser(file)\"" \
+      tk_dialog .error $__langauge(error) [langExp %s $__browser(file) $__language(browser,15)]\
           error 0 OK
       return
     }
     if {$__browser(exists) && ![file exists $__browser(dirEntry)]} {
-      tk_dialog .error ERROR \
-          "Directory does not exist: \"$__browser(dirEntry)\""   error 0 OK
+      tk_dialog .error $__langauge(error) \
+        [langExp "%s" $__browser(dirEntry) $__language(browser,16)]   error 0 $__language(ok)
       return
     }
   }
