@@ -33,12 +33,47 @@ if {[info exists tk_version]} {
   wm withdraw .
 }
 
+
+
+############################################################
+#             Ask for a module and a language
+############################################################
+source [lindex $argv 0]/system.tcl
+source [lindex $argv 0]/language.tcl
+set libPath [lindex $argv 1]
+if {[llength $argv] != 2} {
+  if {![regexp "(.*)/(.*)" [lindex $argv 2] all __modLang __modName]} {
+    set __modName [lindex $argv 2]
+    if {[file exists $libPath/$__system(language)/$__modName]} {
+      set __modLang $__system(language)
+    } else {
+      set __modLang english
+    }
+  }
+} else {
+  set __modName ""
+  askForInfo
+}
+set verfile $libPath/$__modLang/$__modName/version
+if {[file exists $verfile]} {
+  set FILE [open $verfile]
+  set module(version) [gets $FILE]
+  close $FILE
+} else {
+  set module(version) ""
+}
+loadLanguageInfo
+unset verfile
+set argv [concat [list [lindex $argv 0] $libPath/$__modLang/$__modName] [lrange $argv 3 end]]
+
+
+
 ############################################################
 #                     Sourceing function files
 ############################################################
-foreach __file {parse types menus help functions util save bytecompile
-  setup generate fillouts edit versionUpdate dialog color combo import export
-  setPages details load system browser mail} {
+foreach __file {parse types menus help functions util save
+  bytecompile setup generate fillouts edit dialog color combo
+  import export setPages details load browser mail} {
   source [lindex $argv 0]/$__file.tcl
 }
 
@@ -55,15 +90,14 @@ proc import {file} {
 #           and now for the copyright notice
 ############################################################
 if {[lindex $argv 2] != "bytecompile"} {
-  puts "The Dotfile Generator version 2.2 Copyright (C) 1995-1997 Jesper K. Pedersen"
+  puts "The Dotfile Generator version 2.4 Copyright (C) 1995-1997 Jesper K. Pedersen"
   puts "The Dotfile Generator comes with ABSOLUTELY NO WARRANTY; for details"
   puts "see the \"Help\" menu. This is free software, and you are welcome to"
   puts "redistribute it under certain conditions; see the \"Help\" menu"
   puts "for details."
-}
-if {$argv == ""} {
-  puts "To start this program, type wish <template file> <dotfile path> <module path>"
-  exit -1
+
+  # load the locale command(s) if it exist
+  loadlocalCommand
 }
 
 set __changed 0
@@ -71,8 +105,8 @@ set __fillOutCounter 0    ;# just to avoid testing existens
 set __editInfo(trace) 0
 set __editInfo(menuload) 0
 set __clipboardName ""    ;# just to avoid testing existens
-set __editInfo(version) "2.2"
-set __editInfo(releaseDate) "Sun Dec 21"
+set __editInfo(version) "2.4"
+set __editInfo(releaseDate) "Thu Dec 16"
 set __editInfo(name) ""   ;# just to avoid testing existens
 set __busy {}
 set __editInfo(loadFile) ""
@@ -91,7 +125,6 @@ if {$__bc == "loadedBCFile"} {
 } else {
   set loadedByteCompileFile 0
 }
-
 source [lindex $argv 1]/main.template
 parseFile
 if {$__bc != "loadedBCFile"} {
@@ -101,7 +134,6 @@ if {$__bc != "loadedBCFile"} {
 if {[file exists [lindex $argv 1]/local.template] && !$loadedByteCompileFile} {
   import local.template
 }
-
 if {$__bc == "doByteCompile"} {
   byteCompileFile
 }
@@ -144,7 +176,7 @@ if {![info exists setup(saveOnGenerate)]} {
   set setup(saveOnGenerate) 0
 }
 if {![info exists module(overAllDesc)]} {
-  set module(overAllDesc) "This file has been auto generated\nby the $module(name) module for the Dotfile Generator\non \[exec date\]"
+  set module(overAllDesc) [langExp "%d" "\[exec date\]" [langExp "%s" $module(name) $__language(dotfile,4)]]
 }
 set __pathProgsNames(pre_generate) "/Pre commands"
 set __pathProgsNames(post_generate) "/Post commands"
@@ -165,7 +197,6 @@ if {[lindex $argv 2] == "convertExports"} {
   saveFile  [lindex $argv 4]
   exit
 } else {
-
   initialize_and_load
 }
 ############################################################
