@@ -28,6 +28,7 @@
 proc fillout_list {prefix path name entryname {counter -1}} {
   global __widgetArgs __editInfo __children __activeNivau __clean
   global __fillOutCounter __fillList __answers __changeFunc __initFunc
+  global __language
   set function $__editInfo(name)
   set type $__widgetArgs(${function}__${name}__tp)
 
@@ -79,9 +80,15 @@ proc fillout_list {prefix path name entryname {counter -1}} {
     pack [frame $w.line -height 0.1c -relief sunken -bd 1] -fill x -expand yes
 
     ### packing the OK buton
-    button $w.ok -text OK -command "fillOut_OK $entryname $w"
+    button $w.ok -text $__language(ok) -command "fillOut_OK $entryname $w"
+    if {$new} {
+      button $w.cancel -text $__language(cancel) -command "set __destroyed 1;destroy $w"
+    }
     bind $w.ok <Destroy> "set __destroyed 1"
     pack $w.ok -side left -expand 1
+    if {$new} {
+      pack $w.cancel -side left -expand 1
+    }
 
     update
     grabSet $w
@@ -243,8 +250,10 @@ proc fillOutInsert {path prefix name index key state keysymb} {
     if {$type == "entry"} {
       tkEntryBackspace $path.2
     } else {
-      $path.2 delete $index
-      set index [$path.2 index "$index -1c"]
+      if {$index != "1.0"} {
+        $path.2 delete "$index -1c"
+        set index [$path.2 index $index]
+      }
     }
   }
   if {$keysymb == "Delete" || ($keysymb == "d" && $state&4)} {
@@ -326,7 +335,7 @@ proc fillOutInsert {path prefix name index key state keysymb} {
   if {$specialKey == "Delete"} {
     set count -1
   } elseif {$specialKey == "BackSpace"} {
-    if {$index != 0} {
+    if {($index != 0 && $type =="entry") || ($index != "1.0" && $type == "text")} {
       set count -1
     } else {
       set count 0
@@ -363,7 +372,8 @@ proc fillOutInsert {path prefix name index key state keysymb} {
     set insertNext 1
 
     ### BackSpace
-    if {$specialKey == "BackSpace" && $end == $index-1} {
+    if {$specialKey == "BackSpace" && 
+    (($end == $index-1 && $type == "entry") || ($end == $index && $type == "text")) } {
       set count [expr -($end-$start+1)]
       if {$type == "entry"} {
         $path.2 delete $start $end
@@ -494,7 +504,7 @@ proc fillOutSet {path prefix name x y} {
 }
 
 proc fillOutPaste {path prefix name x y} {
-  global __fillList __widgetArgs __editInfo
+  global __fillList __widgetArgs __editInfo __language
   set function $__editInfo(name)
   set type $__widgetArgs(${function}__${name}__tp)
   
@@ -507,7 +517,7 @@ proc fillOutPaste {path prefix name x y} {
 
   ### decide the length of the clipboard
   if {[catch "selection get"]} {
-    error "No selection!"
+    error $__language(fillouts,1)
   }
   set selection [selection get]
   set len [string length $selection]
@@ -518,7 +528,7 @@ proc fillOutPaste {path prefix name x y} {
     set start [lindex $elm 0]
     set end [lindex $elm 1]
     if {$index > $start && $index <= $end} {
-      error "You can not paste at the current position of the fillout element"
+      error $__language(fillouts,2)
     }
 
     if {$index <= $start} {
@@ -749,7 +759,7 @@ proc fillOut_setDefault {function name prefix default} {
 ### or kill the window on a page, which configures a FillOutElm
 ######################################################################
 proc fillOut_OK {entryname w} {
-  global __widgetArgs __editInfo __destroyed __func
+  global __widgetArgs __editInfo __destroyed __func __language
   upvar \#0 __errmsg errmsg
   set function $__editInfo(name)
   ### expand should not be used in pageEnd!
@@ -757,7 +767,7 @@ proc fillOut_OK {entryname w} {
   ###  set __func ""; # used by expand
   set err [uplevel \#0 catch \{$__widgetArgs(${function}__${entryname}__pageEnd)\} __errmsg]
   if {$err} {
-    tk_dialog .errmsg "Error in page" $errmsg error 0 OK
+    tk_dialog .errmsg $__language(fillouts,3) $errmsg error 0 $__language(ok)
     return
   }
   catch {destroy $w}
