@@ -223,10 +223,10 @@ proc setDesc {desc widget} {
 #               Quit
 ######################################################################
 proc quit {} {
-  global __changed
+  global __changed __language
   if {$__changed} {
-    set answer [tk_dialog .dialog "Unsaved Information" \
-		    "There's information, which haven't been saved what do you want to do" questhead 2 Quit "Dont Quit" Save "Save As..."]
+    set answer [tk_dialog .dialog $__language(functions,1) \
+		    $__language(functions,2) questhead 2 $__language(functions,3) $__language(functions,4) $__language(functions,5) $__language(functions,6)]
     if {$answer == 2 || $answer == 3} {
       if {[checkPage] == 0} {
         return
@@ -260,7 +260,7 @@ proc expand {name {array ""}} {
 # bottom of the configuration page
 ######################################################################
 proc setWhatToGenerate {} {
-  global setup __editInfo
+  global setup __editInfo __language
   if {![winfo exists .edit.save]} return
 
   if {$setup(whatToGenerate) == "one" || $setup(whatToGenerate) == "all"} {
@@ -271,17 +271,17 @@ proc setWhatToGenerate {} {
       pack [label .edit.save.label]
     }
     if {$setup(whatToGenerate) == "one"} {
-      .edit.save.label configure -text "Only this page will be generated"
+      .edit.save.label configure -text $__language(functions,7)
     } else {
-      .edit.save.label configure -text "All pages will be generated"
+      .edit.save.label configure -text $__language(functions,8)
     }
   } else { ;# selected
     if {[winfo exist .edit.save.label]} {
       catch "destroy .edit.save.label"
     }
     if {![winfo exist .edit.save.yes]} {
-      radiobutton .edit.save.yes -text "Will be generated" -value 1
-      radiobutton .edit.save.no -text "Will not be generated" -value 0
+      radiobutton .edit.save.yes -text $__language(functions,9) -value 1
+      radiobutton .edit.save.no -text $__language(functions,10) -value 0
       pack .edit.save.yes .edit.save.no -side left -expand 1
     }
     .edit.save.yes configure -variable __saveInfo($__editInfo(name))
