@@ -6,7 +6,7 @@ set __help_loading 0
 ############################################################
 proc help`helpOnHelp {} {
   global __help_headers __help_history __help_history_index __help_loading
-  global __help_grab __SN __BITMAPDIR argv
+  global __help_grab __SN __BITMAPDIR argv __language __system
   
   if {[winfo exist .manpage]} {
     wm deiconify .manpage
@@ -28,7 +28,7 @@ proc help`helpOnHelp {} {
   # creating the please wait window
   toplevel .wait
   label .wait.icon -bitmap info
-  label .wait.label -text "Loading help,\nplease wait..." \
+  label .wait.label -text $__language(help,1) \
       -font "-*-helvetica-medium-r-*-*-20-*-*-*-*-*-*-*"
   pack .wait.icon .wait.label -side left -padx  10
   wm withdraw .wait
@@ -41,7 +41,7 @@ proc help`helpOnHelp {} {
   wm deiconify .wait
   update
   toplevel .manpage
-  wm title .manpage "Dotfile Help"
+  wm title .manpage $__language(help,2)
   if {[grab current .] != ""} {
     set __help_grab [grab current .]
     grabSet .manpage
@@ -71,10 +71,14 @@ proc help`helpOnHelp {} {
   bind $listbox <Configure> "helpResize"
   
   ### source the man definition
-  if {[file exists [lindex $argv 1]/generatedHelp]} {
-    source [lindex $argv 1]/generatedHelp
+  if {[file exists [lindex $argv 1]/generatedHelp.$__system(language)]} {
+    source [lindex $argv 1]/generatedHelp.$__system(language)
+  } elseif {[file exists [lindex $argv 0]/generatedHelp.$__system(language)]} {
+    source [lindex $argv 0]/generatedHelp.$__system(language)
+  } elseif {[file exists [lindex $argv 1]/generatedHelp.english]} {
+    source [lindex $argv 1]/generatedHelp.english
   } else {
-    source [lindex $argv 0]/generatedHelp
+    source [lindex $argv 0]/generatedHelp.english
   }
   createHelpPage $prefix
   $prefix configure -state disabled
@@ -97,7 +101,7 @@ proc help`helpOnHelp {} {
   button .manpage.buttons.back -bitmap @$__BITMAPDIR/Left -command help`back
   button .manpage.buttons.forward -bitmap @$__BITMAPDIR/Right \
       -command help`forward 
-  button .manpage.buttons.ok  -text "Close" -command {
+  button .manpage.buttons.ok  -text $__language(help,3) -command {
     global __help_grab
     wm iconify .manpage
     if {[info exists __help_grab]} {
@@ -120,7 +124,7 @@ proc help`helpOnHelp {} {
   pack .manpage.frame -expand 1 -fill both
 
   ### create the search entry
-  label .manpage.buttons.label -text "Search String: "
+  label .manpage.buttons.label -text $__language(help,4)
   entry .manpage.buttons.search -textvariable __help_search 
   button .manpage.buttons.up -bitmap @$__BITMAPDIR/Up \
       -command "__help_search backwards"
@@ -182,6 +186,7 @@ proc help`indexBrowse {} {
 ############################################################
 proc help`gotoTag {tag} {
   global __help_ref __help_history __help_history_index __SN __help_loading
+  global  __language
 
   # test wether an other help search is in progress
   if {${__help_loading}} return
@@ -203,7 +208,7 @@ proc help`gotoTag {tag} {
   if {[info exists __help_ref($tag)]} {
     $text yview [set __help_ref($tag)]
   } else {
-    error "The tag \"$tag\" does not exist."
+    error [langExp %s $tag $__language(help,5)]
   }
 }
   
@@ -275,7 +280,7 @@ proc help`add {path token} {
 # return - nothing
 ############################################################
 proc help`lookUp {path} {
-  global __help_helpindex
+  global __help_helpindex __language
 
   # try to match the name with something in the helpindex
   # until it matches
@@ -287,7 +292,7 @@ proc help`lookUp {path} {
     }
   }
   if {$i == 0} {
-    error "Lookup couldn't match string \"$path\""
+    error [langExp %s $path $__language(help,7)]
   }
 
   help`gotoTag $tag
@@ -298,7 +303,7 @@ proc help`lookUp {path} {
 # direction - forwards or backwards
 ############################################################
 proc __help_search {direction {start ""} } {
-  global __help_search __SN __help_history __help_history_index
+  global __help_search __SN __help_history __help_history_index __language
   set text $__SN(help`text)
   set back $__SN(help`back)
   set forward $__SN(help`forward)
@@ -334,7 +339,7 @@ proc __help_search {direction {start ""} } {
   set index [$text search -nocase -count count -- ${__help_search} 1.0]
   while {$index  != ""} {
     if {$count == 0} {
-      error "The pattern match the empty string" \
+      error $__language(help,8) \
 	  help_search_empty_string
     }
     set next [$text index $index+${count}c]
@@ -366,12 +371,12 @@ proc __help_search {direction {start ""} } {
   } else {
     if {$direction == "forwards"} {
       set new_start 1.0
-      set new_text beginning
+      set new_text $__language(help,22)
     } else {
       set new_start end
-      set new_text end
+      set new_text $__language(help,23)
     }
-    set answer [tk_dialog .notfound "Text not found" "Text not found. Start from the $new_text ?" questhead 0 Yes No]
+    set answer [tk_dialog .notfound $__language(help,9) [langExp %s $new_text $__language(help,10)] questhead 0 $__language(yes) $__language(no)]
     if {$answer == 0} {
       __help_search $direction $new_start
     }
@@ -407,25 +412,25 @@ proc help {name path} {
 #                   show the about box
 ############################################################
 proc about {} {
-  global module __editInfo argv
+  global module __editInfo argv __language
 
-  set w [makeTempWindow "About"]
+  set w [makeTempWindow $__language(help,11)]
 
 	image create photo GeneratorLogo \
       -file [lindex $argv 0]/bitmaps/GeneratorLogo.gif
 	label $w.label -image GeneratorLogo
 
-  label $w.1 -text "Author:" -justify left -anchor w 
+  label $w.1 -text $__language(help,12) -justify left -anchor w 
   label $w.2 -text "Jesper K. Pedersen\nOdense University\nDenmark" \
       -justify left -anchor w 
-  label $w.3 -text "Version: $__editInfo(version)" -anchor w 
-  label $w.4 -text "Release Date: $__editInfo(releaseDate)" -anchor w 
+  label $w.3 -text "$__language(help,13): $__editInfo(version)" -anchor w 
+  label $w.4 -text "$__language(help,14): $__editInfo(releaseDate)" -anchor w 
   label $w.space -anchor w 
-  label $w.5 -text "The $module(name) module" -anchor w 
-  label $w.6 -text "Creator:" -anchor w 
+  label $w.5 -text [langExp %s $module(name) $__language(help,15)] -anchor w 
+  label $w.6 -text "$__language(help,17):" -anchor w 
   label $w.7 -text $module(creator) -justify left -anchor w 
-  label $w.8 -text "Version: $module(version)" -anchor w 
-  button $w.ok -text OK -command "destroy $w"
+  label $w.8 -text "$__language(help,13): $module(version)" -anchor w 
+  button $w.ok -text $__language(ok) -command "destroy $w"
   
   pack $w.label -pady 5
   pack $w.1 -padx 20 -fill x -expand 1 -anchor w
@@ -446,7 +451,7 @@ proc about {} {
 ############################################################
 proc listbox_help {path name y helpPath} {
 
-  global __widgetArgs __editInfo
+  global __widgetArgs __editInfo __language
   set function $__editInfo(name)
   set index [$path.box nearest $y]
   set entries $__widgetArgs(${function}__${name}__entries)
@@ -497,7 +502,7 @@ proc listbox_help {path name y helpPath} {
         $endY > $comboSy && $startY < $comboEndY} {
       set w [makeTempWindow Help]
       pack [label $w.label -text "$text\n\n$help" -wraplength 500 -justify left]
-      pack [button $w.ok -text "OK" -command "destroy $w"]
+      pack [button $w.ok -text $__language(ok) -command "destroy $w"]
       wm withdraw $w
       update idletasks
       set x [expr [winfo screenwidth $w]/2 - [winfo reqwidth $w]/2 \
@@ -539,9 +544,9 @@ proc menu_help {name index path} {
 }
 
 proc showFile {file} {
-  global argv
+  global argv __language
   set w [makeTempWindow ""]
-  button $w.ok -text "OK" -command "catch {destroy $w}"
+  button $w.ok -text $__language(ok) -command "catch {destroy $w}"
   pack $w.ok -side bottom
 
   text $w.mesg -yscrollcommand "$w.scroll set"
@@ -556,18 +561,17 @@ proc showFile {file} {
 }
 
 proc startBrowser {url} {
-  global __system __startingBrowser
+  global __system __startingBrowser __language
   if {[info exists __startingBrowser]} return
 
   set w [toplevel .browser]
   wm transient .browser
 
   if {$__system(browser) == ""} {
-    label .browser.label -text \
-      "\nNo WWW browser installed\n"
+    label .browser.label -text $__language(help,19)
   } else {
     label .browser.label -text \
-      "\nStarting external WWW browser: $__system(browser)\nplease wait....\n"
+      "\n[langExp %s $__system(browser) $__language(help,20)]\n"
     eval "exec $__system(browser) $url > /dev/null  &"
   }
   pack .browser.label
