@@ -19,6 +19,7 @@
 ### located in.
 ######################################################################
 proc createMenu {} {
+  global  __language
   set bar [frame .bar]
   pack $bar -fill x
 
@@ -37,38 +38,37 @@ proc createMenu {} {
   
   ### File
   set file $bar.file.menu
-  $file add command -label Generate     -command generate
-  $file add command -label "Regenerate this page" -command regenerate
-  $file add command -label Save         -command save
-  $file add command -label "Save As..." -command "saveOrExport user-save"
-  $file add command -label "Export..."  -command "saveOrExport user-export"
-  $file add command -label "Reload..."  -command "loadPage 0"
+  $file add command -label $__language(menus,1) -command generate
+  $file add command -label $__language(menus,2) -command regenerate
+  $file add command -label $__language(menus,3) -command save
+  $file add command -label $__language(menus,4) -command "saveOrExport user-save"
+  $file add command -label $__language(menus,5) -command "saveOrExport user-export"
+  $file add command -label $__language(menus,6) -command "loadPage 0"
   $file add separator
-  $file add command -label Quit         -command quit
+  $file add command -label $__language(menus,7) -command quit
 
   ### Setup
   set setup $bar.setup.menu
-  $setup add command -label "Options..."  -command setup
-  $setup add command -label "Manage Save/Export Files..." \
-      -command manageSaveFiles
+  $setup add command -label $__language(menus,8) -command setup
+  $setup add command -label $__language(menus,9) -command manageSaveFiles
 
   ### Mail
   set mail $bar.mail.menu
-  $mail add command -label "Comment/Suggestion..." \
+  $mail add command -label $__language(menus,10) \
     -command "mail`comment_bug Comment/Suggestion"
-  $mail add command -label "Bug Report..." \
+  $mail add command -label $__language(menus,11) \
     -command "mail`comment_bug {Bug Report}"
-  $mail add command -label "Postcard..." -command mail`postcard
+  $mail add command -label $__language(menus,12) -command mail`postcard
   
   ### help
   set help $bar.help.menu
-  $help add command -label "About..." -command about
-  $help add command -label "Help Page" -command help`helpOnHelp
-  $help add command -label "How to use the output" \
+  $help add command -label $__language(menus,13) -command about
+  $help add command -label $__language(menus,14) -command help`helpOnHelp
+  $help add command -label $__language(menus,15) \
     -command "help`gotoTag howToUse"
   $help add separator
-  $help add command -label Warranty -command "showFile Warranty"
-  $help add command -label Copying -command "showFile Copying"
+  $help add command -label $__language(menus,16) -command "showFile Warranty"
+  $help add command -label $__language(menus,17) -command "showFile Copying"
 
   ### The busy indicator
   label .busy -font fixed -justify left -anchor w
@@ -170,28 +170,8 @@ proc travelMenu {path name bitmap offset x y} {
   set __editInfo(menuload) 1
 
   
-#   ### check the page before we leave it.
-#   if {[checkPage] == 0} {
-#     set __editInfo(menuload) 0
-#     return
-#   }
-
   startBusy "Loading menu...."
 
-#   ### unlink variables on the page we left
-#   if {$__editInfo(name) != ""} {
-#     unlink $__editInfo(name) top ""
-#     catch {unset __activeNivau}
-#   }
-
-#   ### getting the size of the configuration window and destroying it.
-#   if {[winfo exists .edit]} {
-#     if {![regexp {^[0-9]+x[0-9]+([+-][0-9]+[+-][0-9]+)$} [wm geometry .edit] all __editInfo(windowLocation)]} {
-#       catch "unset __editInfo(windowLocation)"
-#     }
-#     destroy .edit
-#     catch "unset __var2path"
-#   }
     
   ### get the location of the event
   if {![regexp {^([0-9]+)x([0-9]+)([+-][0-9]+)([+-][0-9]+)$} \
@@ -228,7 +208,6 @@ proc travelMenu {path name bitmap offset x y} {
   }
 
   reconfigureMenu
-#  set __editInfo(name) ""
   endBusy
   set __editInfo(menuload) 0
 
@@ -261,129 +240,13 @@ proc countSubOpenSubPages {page} {
 
 
 
-
-# Mon May 26 16:10:36 1997 -- Jesper Pedersen
-# This function should be replace by travelMenu
-# ############################################################
-# # This is the function which takes care of the menu's
-# ############################################################
-# proc subType {type} {
-#   global __subPath  __menu2funk __editInfo argv __var2path module __windows
-#   global __activeNivau
-  
-#   ### checking if a page is being loaded
-#   if {$__editInfo(menuload)} return
-#   set __editInfo(menuload) 1
-
-#   ### check the page before we leave it.
-#   if {[checkPage] == 0} {
-#     set __editInfo(menuload) 0
-#     return
-#   }
-
-#   startBusy "Loading menu...."
-
-#   ### unlink variables on the page we left
-#   if {$__editInfo(name) != ""} {
-#     unlink $__editInfo(name) top ""
-#     catch {unset __activeNivau}
-#   }
-
-#   ### getting the size of the configuration window and destroying it.
-#   if {[winfo exists .edit]} {
-#     if {![regexp {^[0-9]+x[0-9]+([+-][0-9]+[+-][0-9]+)$} [wm geometry .edit] all __editInfo(windowLocation)]} {
-#       catch "unset __editInfo(windowLocation)"
-#     }
-#     destroy .edit
-#     catch "unset __var2path"
-#   }
-
-#   ### configure the text widget
-#   .menu configure -state normal
-#   catch "destroy [info commands .menu.*]"
-#   eval .menu tag delete [.menu tag names]
-#   .menu delete 1.0 end
-
-#   set i 0
-#   set level 0
-
-#   ### run through all the previous folders
-#   set past [split $type /]
-#   set past [concat $module(name) [lrange $past 1 [expr [llength $past]-2]]]
-#   set prefix "/"
-#   foreach but $past {
-#     set index [.menu index insert]
-#     label .menu.$i -bitmap @[lindex $argv 0]/bitmaps/act_folder.xbm
-#     .menu insert insert [space $level]
-#     .menu window create insert -window .menu.$i
-#     .menu insert insert " $but\n"
-#     .menu tag add tag$i $index insert
-#     if {$but == $module(name)} {
-#       .menu tag bind tag$i <1> "subType {/}"
-#       bind .menu.$i <1> "subType {/};break"
-#     } else {
-#       .menu tag bind tag$i <1> "subType {$prefix$but/}"
-#       bind .menu.$i <1> "subType {$prefix$but/};break"
-#       append prefix $but/
-#     }
-#     incr level 5
-#     incr i
-#   }
-
-#   ### run through the menus of this page
-#   foreach but $__subPath($type) {
-#     set index [.menu index insert]
-#     .menu insert insert [space $level]
-#     if {[info exists __menu2funk($type$but)]} {
-#       label .menu.$i -bitmap @[lindex $argv 0]/bitmaps/file.xbm
-#       .menu window create insert -window .menu.$i
-#       .menu insert insert " $but\n"
-#       .menu tag add tag$i $index insert
-#       .menu tag bind tag$i <1> "loadMenu $__menu2funk($type$but)"
-#       bind .menu.$i <1> "loadMenu $__menu2funk($type$but);break"
-#     } else {
-#       label .menu.$i -bitmap @[lindex $argv 0]/bitmaps/folder.xbm
-#       .menu window create insert -window .menu.$i
-#       .menu insert insert " $but\n"
-#       .menu tag add tag$i $index insert
-#       .menu tag bind tag$i <1> "subType {$type$but/}"
-#       bind .menu.$i <1> "subType {$type$but/};break"
-#     }
-#     incr i
-#   }
-
-#   ### binding hilight for all the tags
-#   set fg [.menu cget -foreground]
-#   set bg [.menu cget -background]
-#   for {set j 0} {$j < $i} {incr j} {
-#     .menu tag bind tag$j <Enter> \
-#         ".menu tag configure tag$j -foreground $bg -background $fg
-#          .menu.$j configure -foreground $bg -background $fg"
-#     .menu tag bind tag$j <Leave> \
-#         ".menu tag configure tag$j -foreground $fg -background $bg
-#          .menu.$j configure -foreground $fg -background $bg"
-    
-#     bind .menu.$j <Enter> \
-#         ".menu tag configure tag$j -foreground $bg -background $fg
-#          .menu.$j configure -foreground $bg -background $fg"
-#     bind .menu.$j <Leave> \
-#         ".menu tag configure tag$j -foreground $fg -background $bg
-#          .menu.$j configure -foreground $fg -background $bg"
-#   }
-#   .menu configure -state disabled
-#   reconfigureMenu
-#   set __editInfo(name) ""
-#   endBusy
-#   set __editInfo(menuload) 0
-# }   
-
 ############################################################
 # This function is called when a menu page is about to be
 # created. It is here all initialization is done.
 ############################################################
 proc loadMenu {function} {
   global __editInfo __children __pathProgsNames __activeNivau __changeFunc 
-  global __desc __showPage __clean __var2path module  __windows
+  global __desc __showPage __clean __var2path module  __windows __language
 
   # check that we are not loading a menu
   # which could happend if the user choose a new menu to fast.
@@ -416,7 +279,7 @@ proc loadMenu {function} {
     return
   }
 
-  startBusy "Loading page..."
+  startBusy $__language(menus,18)
   
 
 
@@ -583,11 +446,11 @@ proc changeAll {name} {
 ###
 ######################################################################
 proc checkPage {} {
-  global __editInfo __pageEnd __windows
+  global __editInfo __pageEnd __windows __language
   set function $__editInfo(name)
   if {$function == ""} return 
 
-  startBusy "Validating page..."
+  startBusy $__language(menus,19)
   saveDefinition print
   proc print {args} {
     error "You can not Print in the PageEnd function"
@@ -621,7 +484,7 @@ proc checkPage {} {
       pack .edit.options -after .edit.name -expand 1 -fill both -expand 1 
       packAll .edit.options $function 0
     }
-    tk_dialog .errmsg "Error in page" $errmsg error 0 OK
+    tk_dialog .errmsg $__language(menus,20) $errmsg error 0 $__language(ok)
     loadDefinition print
     linkVars $function __$function top
     endBusy
