@@ -34,7 +34,7 @@ proc save {} {
 ### description of the savefile and then save into this file
 ######################################################################
 proc saveOrExport {type {fileName {}}} {
-  global module __system argv __fileName __content
+  global module __system argv __fileName __content __language
   if {$fileName == ""} {
     ### call pageEnd
     if {[checkPage] == 0} return
@@ -55,7 +55,7 @@ proc saveOrExport {type {fileName {}}} {
   set w [makeTempWindow "$dir - Description"]
 
   frame $w.filename
-  label $w.filename.label -text "Relative file name:"
+  label $w.filename.label -text $__language(save,1)
   entry $w.filename.entry -textvariable __fileName
   button $w.filename.button \
       -bitmap @[lindex $argv 0]/bitmaps/folder_center.xbm \
@@ -67,16 +67,16 @@ proc saveOrExport {type {fileName {}}} {
       "
   bind $w.filename.entry <Return> "testIfElmExist $w $type"
   label $w.filename.after \
-      -text "(files will be placed in ~/.dotfile/$module(name)/${dir}-files/)"
+    -text "([langExp %s ~/.dotfile/$module(name)/${dir}-files/ $__language(save,2)])"
   pack $w.filename
   pack $w.filename.label $w.filename.entry $w.filename.button $w.filename.after\
       -side left
-  label $w.title -text "Title:"
+  label $w.title -text $__language(save,3)
   text $w.titleText -width 50 -height 4 -wrap word
-  label $w.desc -text "Description:"
+  label $w.desc -text $__language(save,4)
   text $w.descText -width 50 -height 7 -wrap word
   label $w.command -text \
-      "Tcl Command to give more information about $dir file:"
+    [langExp %s $dir $__language(save,5)]
   text $w.commandText -width 50 -height 7
   pack $w.title
   pack $w.titleText -fill both -expand 1
@@ -85,7 +85,7 @@ proc saveOrExport {type {fileName {}}} {
   pack $w.command
   pack $w.commandText -fill both -expand 1
 
-  label $w.help -wraplength 500 -justify left -text "You have to give the $dir file a title and a description. This information is shown in the load page, which comes up when you start the Dotfile Generator, or when you press the \"Reload\" button."
+  label $w.help -wraplength 500 -justify left -text [langExp %s $dir $__language(save,7)]
   pack $w.help
 
   if {$fileName != ""} {
@@ -95,8 +95,8 @@ proc saveOrExport {type {fileName {}}} {
     set __fileName ""
     set edit 0
   }
-  button $w.ok -text OK -command "saveAsEnd $w $dir ok \$__fileName $edit"
-  button $w.cancel -text Cancel \
+  button $w.ok -text $__language(ok) -command "saveAsEnd $w $dir ok \$__fileName $edit"
+  button $w.cancel -text $__language(cancel) \
       -command "saveAsEnd $w $dir cancel \$__fileName 0"
   pack $w.cancel $w.ok -side right
 
@@ -132,12 +132,11 @@ proc testIfElmExist {w type} {
 ### information to the saveAs dialogbox
 ######################################################################
 proc saveAsEnd {path type method fileName edit} {
-  global __content module __editInfo __activeNivau
+  global __content module __editInfo __activeNivau __language
 
   if {$method == "ok"} {
     if {!$edit && [file dirname $fileName] != "."} {
-      tk_dialog .error "Error" "The filename may not not be with a path!"\
-          error 0 OK
+      tk_dialog .error $__language(error) $__language(save,9) error 0 $__language(ok)
       return
     }
 
@@ -146,7 +145,7 @@ proc saveAsEnd {path type method fileName edit} {
     }
     if {[file exists [myGlob ~/].dotfile/$module(name)/$type-files/$fileName] &&
       !$edit} {
-      set answer [tk_dialog .warning "FILE EXISTS" "File \"$fileName\" allready exists, Do you want to owerwrite?!" questhead 0 No Yes]
+      set answer [tk_dialog .warning $__language(save,10) [langExp %s $fileName $__language(save,11)] questhead 0 $__language(no) $__language(yes)]
       if {$answer == 0} return
     }
     set fun $__editInfo(name)
@@ -183,18 +182,19 @@ proc saveAsEnd {path type method fileName edit} {
 proc saveFile {fileName} {
   global module __progList __changed __saveInfo __children __widgetArgs 
   global __fillList __fillOutCounter setup __editInfo __state __hash __clean
+  global __language
   
   set saved {}
 
   ### creating the "please wait" window
-  timeWindow [expr 6+[llength $__progList]] "Saving" "Saving...Please Wait"
+  timeWindow [expr 6+[llength $__progList]] $__language(save,13) $__language(save,14)
 
   set FILE [open $fileName w]
 
   puts $FILE "$__hash\n\# Dotfile Generator version $__editInfo(version)\n\# $module(name) module version $module(version)\n$__hash\n"
   incrTimeWindow
 
-  puts $FILE "timeWindow [expr 3+[llength $__progList]]  Loading \"Loading...please wait\""
+  puts $FILE "timeWindow [expr 3+[llength $__progList]]  $__language(save,15) \"$__language(save,16)\""
   
   foreach function $__progList {
     puts $FILE "$__hash\n\# $function\n$__hash"
@@ -255,10 +255,18 @@ proc saveFile {fileName} {
 # save file
 ############################################################  
 proc escape {string} {
-  regsub -all {["#\${}]} $string \\\\\\0 result
-  regsub -all {[[]} $result \\\\\\0 string
-  regsub -all {[]]} $string \\\\\\0 result
-  return $result
+  global tcl_version
+  if {$tcl_version < 8.1} {
+    regsub -all {["#\${}]} $string \\\\\\0 result
+    regsub -all {[[]} $result \\\\\\0 string
+    regsub -all {[]]} $string \\\\\\0 result
+    return $result
+  } else {
+    regsub -all {["#\\$\{\}]} $string \\\\\\0 result
+    regsub -all {[[]} $result \\\\\\0 string
+    regsub -all {[]]} $string \\\\\\0 result
+    return $result
+  }
 }
 
 ############################################################
@@ -428,19 +436,19 @@ proc set_setup {var value} {
 ### This function brings up the "manage save file" dialog
 ######################################################################
 proc manageSaveFiles {} {
-  global __content __fileToLoad
-  set w [makeTempWindow "Manage Save File"]
+  global __content __fileToLoad __language
+  set w [makeTempWindow $__language(save,17)]
   
   label $w.dummy
   set txt [frame $w.text]
   text $txt.text -yscrollcommand "$txt.scroll set" -wrap word \
       -font [$w.dummy cget -font]
   scrollbar $txt.scroll -command "$txt.text yview"
-  button $w.cancel -text Cancel -command "destroy $w"
+  button $w.cancel -text $__language(cancel) -command "destroy $w"
 
-  button $w.configure -text "Configure" \
+  button $w.configure -text $__language(save,18) \
       -command "destroy $w;eval saveOrExport \$__fileToLoad"
-  button $w.remove -text "Remove" -command "destroy $w;removeFile"
+  button $w.remove -text $__language(save,19) -command "destroy $w;removeFile"
 
   pack $w.text -fill both -expand 1
   pack $w.cancel -side right -padx 2 -pady 5
@@ -460,12 +468,12 @@ proc manageSaveFiles {} {
 ### the save file.
 ######################################################################
 proc removeFile {} {
-  global __fileToLoad __system __content module
+  global __fileToLoad __system __content module __language
   set type [lindex $__fileToLoad 0]
   set fileName [lindex $__fileToLoad 1]
   regexp {^user-(.*)$} $type all dir
   
-  set answer [tk_dialog .sure "Remove file" "Are you sure that you want to remove the $dir file called \"$fileName\". The file will be removed from disk too!" questhead 0 No Yes]
+  set answer [tk_dialog .sure $__language(save,20) [langExp %t $dir [langExp %s $fileName $__language(save,21)]] questhead 0 $__language(no) $__language(yes)]
 
   if {$answer == 1} {
     eval exec $__system(rm) \
