@@ -22,7 +22,7 @@
 upvar \#0 setup(generateDefault) generateDefault
 
 proc setup {} {
-  global setup __temp module
+  global setup __temp module __language
 
   if {[winfo exists .setup]} {
     raise .setup
@@ -48,7 +48,7 @@ proc setup {} {
     label .setup.filename.$i.label -text [lindex $elm 1]
     entry .setup.filename.$i.entry -textvariable __temp(dotfile$i) \
 	-bd 2 -relief sunken
-    label .setup.filename.$i.label2 -text "Comment character: "
+    label .setup.filename.$i.label2 -text $__language(setup,1)
     entry .setup.filename.$i.commentChar -textvariable __temp(commentChar$i)\
 	-width 5
     pack .setup.filename.$i.label .setup.filename.$i.entry \
@@ -60,22 +60,22 @@ proc setup {} {
 
   frame .setup.save
   pack .setup.save -expand 1 -fill x
-  checkbutton .setup.save.1 -text "Generate to file" \
+  checkbutton .setup.save.1 -text $__language(setup,2) \
       -variable __temp(file) -anchor w 
-  checkbutton .setup.save.2 -text "Display in window" \
+  checkbutton .setup.save.2 -text $__language(setup,3) \
       -variable __temp(print) -anchor w 
   pack .setup.save.1 .setup.save.2 -fill x -side left -fill x -expand 1
   
-  checkbutton .setup.whatTosave -text "Generate defaults too" \
+  checkbutton .setup.whatTosave -text $__language(setup,4) \
       -variable __temp(generateDefault) -anchor w
 
   pack [frame .setup.whatToGen] -expand 1 -fill x
   radiobutton .setup.whatToGen.onePage -variable __temp(whatToGenerate) \
-      -value one -text "One page"
+      -value one -text $__language(setup,5)
   radiobutton .setup.whatToGen.selected -variable __temp(whatToGenerate) \
-      -value selected -text "Selected pages"
+      -value selected -text $__language(setup,6)
   radiobutton .setup.whatToGen.all -variable __temp(whatToGenerate) \
-      -value all -text "All pages"
+      -value all -text $__language(setup,7)
   pack .setup.whatToGen.onePage .setup.whatToGen.selected .setup.whatToGen.all\
       -side left
   if {[info exists module(onlyGenerateAll)] && $module(onlyGenerateAll)} {
@@ -84,18 +84,18 @@ proc setup {} {
     .setup.whatToGen.all configure -state disabled
   }
   
-  checkbutton .setup.saveOnGenerate -text "Save when generating" \
+  checkbutton .setup.saveOnGenerate -text $__language(setup,8) \
       -variable __temp(saveOnGenerate) -anchor w
   pack .setup.whatTosave .setup.saveOnGenerate -fill both -expand 1
 
   ### place windows
-  checkbutton .setup.place -text "Place windows" \
+  checkbutton .setup.place -text $__language(setup,9) \
       -variable __temp(placeWindows) -anchor w
   pack .setup.place -fill both -expand 1
   
   frame .setup.buttons
   pack .setup.buttons -expand 1 -fill x
-  button .setup.buttons.ok -text "OK" -command {
+  button .setup.buttons.ok -text $__language(ok) -command {
     foreach var {file print whatToGenerate generateDefault saveOnGenerate
       placeWindows} {
       set setup($var) $__temp($var)
@@ -112,7 +112,7 @@ proc setup {} {
     setWhatToGenerate
     catch "destroy .setup"
   }
-  button .setup.buttons.cancel -text "CANCEL" -command {
+  button .setup.buttons.cancel -text $__language(cancel) -command {
     catch "destroy .setup"
   }
  
