@@ -5,3 +5,5 @@ set __system(mv) "mv"
 set __system(tclsh) "tclsh7.4"
 set __system(cp) "cp"
 set __system(mail) ""
+set __system(language) "english"
+set __system(languages) {english japanese}
