@@ -727,13 +727,6 @@ proc pack_menu {path prefix name pack orient row active} {
     set tleft $__widgetArgs(${function}__${name}__text)
     set tright $__widgetArgs(${function}__${name}__textafter)
 
-    # The pack function should NOT take care of setting default values anymore!
-    # Sun Jan 26 12:52:47 1997 -- Jesper Pedersen    
-    # setting the menu to the first element, in case no default settings exist.
-    #     if {![info exists ${prefix}_$name]} {
-    #       set ${prefix}_$name [lindex $entries 0]
-    #     }    
-
     eval frame $w $__TKargs(${function}__${name}__frame)
     eval pack $w -anchor w -side $orient \
       $__TKargs(${function}__${name}__packFrame)
@@ -759,11 +752,6 @@ proc pack_menu {path prefix name pack orient row active} {
       bind $w$elm <3> "help $name $path"
     }
   } else {
-    # The pack function should NOT take care of setting default values anymore!
-    # Sun Jan 26 12:52:47 1997 -- Jesper Pedersen    
-    #     if {![info exists ${prefix}_$name]} {
-    #       set ${prefix}_$name [lindex $entries 0]
-    #     }
     $w.bar configure -textvariable ${prefix}_$name
   }
   bind $w.bar <ButtonPress-3> {
@@ -973,13 +961,6 @@ proc pack_command {path prefix name pack orient row active} {
     }
 
   } else {
-# This seems to be an unappropriated bug fix....
-# I should have the if clause instead, as I have now.    
-# Sun Jan 12 17:02:13 1997 -- Jesper Pedersen    
-#     global ${prefix}_$name
-#     if {![info exists ${prefix}_$name]} {
-#       set ${prefix}_$name $__widgetArgs(${function}__${name}__default)
-#     }
     if {$active} {
       $w.2 configure -command "comandInvoke $w $prefix $name"
       catch unset widget
@@ -1003,22 +984,13 @@ proc pack_command {path prefix name pack orient row active} {
 }
 proc pack_extentry {path prefix name pack orient row active} {
   global __widgetArgs __children __editInfo __scrollBar __traceTable
-  global __TKargs argv
+  global __TKargs argv __language
   set function $__editInfo(name)
   set w $path._$name
   set count $__widgetArgs(${function}__${name}__count)
   set noscissor $__widgetArgs(${function}__${name}__noscissor)
   set maxentries $__widgetArgs(${function}__${name}__maxentries)
   
-  # what do I need a trace for?
-  # Fri Jul 26 06:52:14 1996 -- Jesper Pedersen
-  #   ### remove the trace if it exists
-  #   if {[info exists __traceTable(${function}_$w)]} {
-  #     uplevel \#0 \
-    #         "trace vdelete $__traceTable(${function}_$w) w {trace_scrollbar $w.scroll}"
-  #     unset __traceTable(${function}_$w)
-  #   }
-  
   if {$pack} {
     set text $__widgetArgs(${function}__${name}__text)
     set subOrient $__widgetArgs(${function}__${name}__orient)
@@ -1107,8 +1079,7 @@ proc pack_extentry {path prefix name pack orient row active} {
         menu $w.row$row.edit.menu -tearoff 0 -postcommand "if {\$__clipboardName == {$name}} {$w.row$row.edit.menu entryconfigure 2 -state normal} else {$w.row$row.edit.menu entryconfigure 2 -state disabled}"
 
         ### inserting element into the cut/paste menu
-        foreach elm {
-          {Cut Cut} {Copy Copy} {Paste Paste} {Insert "Insert Blank"}} {
+        foreach elm "{Cut \"$__language(types,2)\"} {Copy \"$__language(types,3)\"} {Paste \"$__language(types,4)\"} {Insert \"$__language(types,5)\"}" {
           $w.row$row.edit.menu add command -label [lindex $elm 1]\
             -command "extEntry[lindex $elm 0] $path $prefix $name [expr $row + $offset]"
         }
@@ -1179,10 +1150,6 @@ proc pack_extentry {path prefix name pack orient row active} {
     $w.new configure -command "newTuple $function $path $prefix $name"
   }
   
-  ### set trace on the scroll value
-  # Fri Jul 26 06:52:14 1996 -- Jesper Pedersen
-  #   trace variable __scrollBar(${prefix}_$name) w "trace_scrollbar $w.scroll"
-  #   set __traceTable(${function}_$w) __scrollBar(${prefix}_$name)
 }
 proc pack_line {path prefix name pack orient row active} {
   global __TKargs __editInfo __widgetArgs
@@ -1667,15 +1634,6 @@ proc trace_listbox {path variable subvar operation} {
     $path selection set $index
   }
 }
-# proc trace_scrollbar {path variable subvar operation} {
-#   upvar $variable x
-#   if {[info command $path] == ""} {
-#     # the scrollbar has disapear, remove the trace
-#     uplevel \#0 trace vdelete ${variable}($subvar) $operation \"trace_scrollbar $path\"
-#     return
-#   }
-#   eval $path set $x($subvar)
-# }
 proc scroll_listbox {path prefix args} {
   global ${prefix}_scroll
   eval $path yview $args
@@ -2075,7 +2033,7 @@ proc showWindow {path prefix name row} {
     ### There seems to be a bug in TK 8.0, so I have to catch errors
     ### from the following commmand
     catch "tkwait visibility $w"
-    if {[grab current $w] != {}} {
+    if {[winfo exists $w] && [grab current $w] != {}} {
       update
       pushGrab [grab status [grab current $w]] $w
       tkwait window $w
